.. _readme_intro_start:

Peddler: the cloud friendly open source e-commerce solution for DIY'ers.
========================================================================

Peddler is an open source, container-based, OpenCart distribution from `Alto9 <https://www.alto9.com>`__.

It's written in Python and Click and is designed to make launching an OpenCart instance as easy as possible.

- `Product Documentation <https://alto9.github.io/peddler/>`__
- `Download Compiled Version  <https://github.com/alto9/peddler/releases>`__

.. _readme_intro_end:

Deploy using docker-compose
---------------------------
``peddler local quickstart``


Deploy using Kubernetes
-----------------------
``peddler k8s quickstart``

License
-------

See the `LICENSE.txt <./LICENSE.txt>`__ for license rights and limitations.

Get the Latest News
-------------------

- **Twitter** - https://twitter.com/alto9cloud
- **Blog** - https://alto9.com/blog/
- **Facebook** - https://www.facebook.com/Alto9Inc
- **LinkedIn** - https://www.linkedin.com/company/alto9

Contributing
------------

Please see `CONTRIBUTING.md <./CONTRIBUTING.md>`__.

Any other questions, mail us at info@alto9.com. We’d love to chat!